@@ -61,6 +61,7 @@ class SerializerOpts(object):
             raise ValueError("`exclude` must be a list or tuple.")
         self.strict = getattr(meta, 'strict', False)
         self.dateformat = getattr(meta, 'dateformat', None)
+        self.json_module = getattr(meta, 'json_module', json)
 
 
 class BaseSerializer(base.SerializerABC):
@@ -142,6 +143,8 @@ class BaseSerializer(base.SerializerABC):
             date format explicitly specified.
         - ``strict``: If ``True``, raise errors during marshalling rather than
             storing them.
+        - ``json_module``: JSON module to use. Defaults to the ``json`` module
+            in the stdlib.
         '''
         pass
 
@@ -179,7 +182,7 @@ class BaseSerializer(base.SerializerABC):
                 self.__data.update(self.extra)
 
     def _update_fields(self, obj):
-        '''Update fields based on the passed in object.'''
+        """Update fields based on the passed in object."""
         # if only __init__ param is specified, only return those fields
         if self.only:
             ret = self.__filter_fields(self.only)
@@ -207,9 +210,9 @@ class BaseSerializer(base.SerializerABC):
         return self.fields
 
     def __set_field_attrs(self, fields_dict):
-        '''Set the parents of all field objects in fields_dict to self, and
+        """Set the parents of all field objects in fields_dict to self, and
         set the dateformat specified in ``class Meta``, if necessary.
-        '''
+        """
         for field_name, field_obj in iteritems(fields_dict):
             if not field_obj.parent:
                 field_obj.parent = self
@@ -221,13 +224,13 @@ class BaseSerializer(base.SerializerABC):
         return fields_dict
 
     def __filter_fields(self, field_names):
-        '''Return only those field_name:field_obj pairs specified by
+        """Return only those field_name:field_obj pairs specified by
         ``field_names``.
 
         :param set field_names: Field names to include in the final
             return dictionary.
         :returns: An OrderedDict of field_name:field_obj pairs.
-        '''
+        """
         # Convert obj to a dict
         obj_marshallable = utils.to_marshallable_type(self.obj,
             field_names=field_names)
@@ -269,19 +272,19 @@ class BaseSerializer(base.SerializerABC):
 
     @property
     def json(self):
-        '''The data as a JSON string.'''
+        """The data as a JSON string."""
         return self.to_json()
 
     @property
     def errors(self):
-        '''Dictionary of errors raised during serialization.'''
+        """Dictionary of errors raised during serialization."""
         return self.marshal.errors
 
     def to_json(self, *args, **kwargs):
         '''Return the JSON representation of the data. Takes the same arguments
         as Pythons built-in ``json.dumps``.
         '''
-        ret = json.dumps(self.data, *args, **kwargs)
+        ret = self.opts.json_module.dumps(self.data, *args, **kwargs)
         # On Python 2, json.dumps returns bytestrings
         # On Python 3, json.dumps returns unicode
         # Ensure that a bytestring is returned
